#!/bin/sh

show_help(){
  echo "
  using install.sh: 
  install.sh [arguments]:

  select [arguments] from:
  kc1 - install kc1 packages (by default)
  kc2 - install kc2 packages
"
}

enclosure=kc1
case $1 in
""|kc1)
  enclosure=kc1
;;
kc2)
  enclosure=kc2
;;
"-help")
  show_help
  exit 0
;;
"--help")
  show_help
  exit 0
;;
*)
  echo "usage: install.sh [kc1|kc2]"
  exit 1
;;
esac

cd `dirname $0`
/bin/sh ./uninstall.sh || exit $?

case `uname -m` in
x86_64|amd64)
  ARG=64
  ;;
*)
  ;;
esac

uname -sr | grep "FreeBSD 1" > /dev/null
if test $? -eq 0; then
  # FBSD >= 10
  uname -sr | grep "FreeBSD 10" > /dev/null
  if test $? -eq 0; then
    pkg_add_command="/usr/sbin/pkg add"
  else
    # FBSD >= 11, в манифесте прописана FreeBSD 10, поэтому используем install -y
    pkg_add_command="/usr/sbin/pkg install -y"
  fi
else
  pkg_add_command="/usr/sbin/pkg_add"
fi

echo "Installing CPRObase..."
# test -e will check if there is exactly one file
test -e cpro-base-4.0.*_0.tbz && \
    $pkg_add_command cpro-base-4.0.*_0.tbz || exit $?

list="cpro-rdr cpro-$enclosure cpro-capilite cpro-curl"
for i in $list; do
  if test x$ARG = x64 && [ -e cpro-rdr-64-4.0.*_0.tbz ]; then
    i="${i}-64"
  fi

  echo "Installing $i..."
  test -e $i-4.0.*_0.tbz && \
      $pkg_add_command $i-4.0.*_0.tbz || exit $?
done

