#!/bin/sh

check_fail() {
    echo 'Error: failed to uninstall CSP packages'
    exit "$1"
}

if uname -sr | grep 'FreeBSD 1' >/dev/null 2>&1 ; then
    # в случае fbsd 10+ проверяем наличие пакетного менеджера pkg
    echo 'N' | pkg --version >/dev/null 2>&1 || check_fail "$?"
    info_command='pkg info'
    del_command='pkg delete -y'
else
    info_command='pkg_info'
    del_command='pkg_delete'
fi

pkglist="$(${info_command} | awk '{print $1}' | grep -e 'rtSupCP' -e 'CPRO' -e 'cpro-')"
rdr_package="$(echo "${pkglist}" | grep 'cpro-rdr-[0-9]')"
base_package="$(echo "${pkglist}" | grep 'base')"
csp_packages="$(
    echo "${pkglist}" \
        | grep -vx -e "${rdr_package}" -e "${base_package}" \
        | xargs
)"

echo "Uninstalling CSP packages..."
if [ -n "${csp_packages}" ] ; then
    ${del_command} ${csp_packages} || check_fail "$?"
fi
if [ -n "${rdr_package}" ] ; then
    ${del_command} ${rdr_package} || check_fail "$?"
fi
if [ -n "${base_package}" ] ; then
    ${del_command} ${base_package} || check_fail "$?"
fi
echo "CSP packages have been successfully uninstalled"
